pub struct InMemoryQueue { /* private fields */ }Expand description
Memory based Queue implementation backed by an efficient background task.
InMemoryQueue::update allows for dynamically changing the queue’s
settings.
Cloning the queue is cheap and just increments a reference counter.
Note: A max_concurrency of 0 processes all requests instantly,
effectively disabling the queue.
Implementations
Sourceimpl InMemoryQueue
impl InMemoryQueue
Sourcepub fn new(
max_concurrency: u16,
remaining: u32,
reset_after: Duration,
total: u32,
) -> Self
pub fn new( max_concurrency: u16, remaining: u32, reset_after: Duration, total: u32, ) -> Self
Sourcepub fn update(
&self,
max_concurrency: u16,
remaining: u32,
reset_after: Duration,
total: u32,
)
pub fn update( &self, max_concurrency: u16, remaining: u32, reset_after: Duration, total: u32, )
Update the queue with new info from the Get Gateway Bot endpoint.
May be regularly called as the bot joins/leaves guilds.
Example
use std::time::Duration;
use twilight_http::Client;
let client = Client::new(token);
let session = client
.gateway()
.authed()
.await?
.model()
.await?
.session_start_limit;
queue.update(
session.max_concurrency,
session.remaining,
Duration::from_millis(session.reset_after),
session.total,
);Panics
Panics if total < remaining.